@@ -9,8 +9,8 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.067-5-gac99ee0
-$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.068';
+# git description: 0.068-7-gaaa7bb9
+$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.069';
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
@@ -143,8 +143,13 @@ sub release_plugins {
 
     push @plugins, 'Signature',
         if $self->sign;
-    push @plugins, [ Twitter => { hash_tags => '#perl #cpan' } ]
-        if $self->tweet;
+    push @plugins, [
+        Twitter => {
+            hash_tags => '#perl #cpan',
+            # TODO: remove the next line when resolved:
+            # https://github.com/dagolden/dist-zilla-plugin-twitter/issues/11
+            tweet_url => 'https://metacpan.org/release/{{$AUTHOR_UC}}/{{$DIST}}-{{$VERSION}}{{$TRIAL}}/',
+        } ] if $self->tweet;
     push @plugins, [ InstallRelease => { install_command => 'cpanm .' } ]
         if $self->install_on_release;
     push @plugins, [ 'GitHub::Update' => { metacpan  => 1 } ]
@@ -265,6 +270,24 @@ sub configure {
         [ AutoPrereqs => $autoprereq_opts ],
         [ Prepender   => $prepender_opts  ],
 
+        # These are requirements that will be inserted on the generated dist,
+        # that indicate that for develop phase (e.g. author/release testing)
+        # certain additional packages are required for full exercise of xt/
+        [ Prereqs => AuthorBundleDevelopRequires => {
+            -phase        => 'develop',
+            -relationship => 'requires',
+
+            # TODO: drop when this is merged and released:
+            # https://github.com/marcel-maint/Dist-Zilla-Plugin-HasVersionTests/pull/2
+            'Test::HasVersion'        => 0,
+
+            # TODO: drop when this is merged and released:
+            # https://github.com/doherty/Dist-Zilla-Plugin-Test-MinimumVersion/pull/7
+            'Test::MinimumVersion'    => 0,
+
+            'Test::ConsistentVersion' => 0,
+        } ],
+
         $self->author_tests,
         $self->meta_provider_plugins,
         $self->release_plugins,
@@ -352,7 +375,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.068 of Dist::Zilla::PluginBundle::RSRCHBOY - released October 09, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.069 of Dist::Zilla::PluginBundle::RSRCHBOY - released October 10, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
